 #!/usr/bin/env python

import json
import sys
import os

class BaseTransformation(object):
    def __init__(self, props_file, full_zk_dump):
        if not os.path.exists(props_file):
            sys.exit("Properties file does not exist at path '{0}'.".format(props_file))
        self.props = json.load(open(props_file))
        self.full_zk_dump = full_zk_dump
        if not os.path.exists(self.full_zk_dump):
            sys.exit("Full zk dump file does not exist at path '{0}'.".format(self.full_zk_dump))

    def get_property(self, name):
        return self.props[name]

    def get_old_fusion(self):
        return self.get_property("fusion.home.old")

    def get_new_fusion(self):
        return self.get_property("fusion.home.new")

    def get_old_chroot(self):
        return self.get_property("chroot.old")

    def get_new_chroot(self):
        return self.get_property("chroot.new")

    def get_api_connect(self):
        return "{0}:{1}".format(self.get_property("api.address.new"), self.get_property("api.port.new"));

    def load_zk_config_props(self):
        self.zk_properties = {}
        prefix = "{}/core/conf/".format(self.get_property("chroot.old"))
        with open(self.full_zk_dump) as f:
            for line in f:
                znode = json.loads(line)
                if znode["path"].startswith(prefix):
                    self.zk_properties[znode["path"][len(prefix):]] = znode["data"]

    def get_zk_property(self, name):
        if self.zk_properties is None:
            self.load_zk_config_props()
        if name in self.zk_properties:
            return self.zk_properties[name]
        else:
            return None

    def read_full_zk_dump(self, path):
        new_chroot = self.get_old_chroot()
        result = []
        with open(self.full_zk_dump) as f:
            for line in f:
                znode = json.loads(line)
                if znode["path"].startswith(new_chroot + path):
                    result.append(json.loads(znode["data"]))
        return result

