#!/usr/bin/env python

import sys
import os
import logging
from shutil import ignore_patterns, rmtree
from distutils.dir_util import copy_tree

from fs_transformation import FSTransformation

CONF_FOLDER = "conf"


def copy_data(fusion_home_old, fusion_home_new):
    old_conf = os.path.join(fusion_home_old, CONF_FOLDER)
    if not os.path.exists(old_conf):
        sys.exit("Old Fusion conf folder doesn't exist at path '{0}'.".format(old_conf))
    new_conf = os.path.join(fusion_home_new, CONF_FOLDER)
    new_conf_backup = os.path.join(fusion_home_new, CONF_FOLDER + "_backup")
    if os.path.exists(new_conf_backup):
        logging.info("Deleting previous run conf back up '{}'".format(new_conf_backup))
        rmtree(new_conf_backup)
    logging.info("Backing up conf from '{}' to '{}'".format(new_conf, new_conf_backup))
    os.rename(new_conf, new_conf_backup)
    logging.info("Copying old conf from '{}' to '{}'".format(old_conf, new_conf))
    copy_tree(old_conf, new_conf, preserve_symlinks=True)

if __name__ == "__main__":
    fsTran = FSTransformation("Copy configuration folder")
    fusion_home_old = fsTran.get_old_fusion()
    fusion_home_new = fsTran.get_new_fusion()
    copy_data(fusion_home_old, fusion_home_new)
