#!/usr/bin/env python

import sys
import os
import logging
from distutils.dir_util import copy_tree
from distutils.file_util import copy_file
from shutil import rmtree

from fs_transformation import FSTransformation

DATA_FOLDER = "data"
ZOOKEPER = "zookeeper"
MY_ID_FILE = "myid"


def copy_data(fusion_home_old, fusion_home_new):
    old_data = os.path.join(fusion_home_old, DATA_FOLDER)
    if not os.path.exists(old_data):
        sys.exit("Old Fusion data folder doesn't exist at path '{0}'.".format(old_data))
    new_data = os.path.join(fusion_home_new, DATA_FOLDER)
    if not os.path.exists(fusion_home_new):
        sys.exit("New Fusion home folder doesn't exist at path '{0}'.".format(fusion_home_new))
    if not os.path.exists(new_data):
        os.makedirs(new_data)
    new_data_backup = os.path.join(fusion_home_new, DATA_FOLDER + "_backup")
    if os.path.exists(new_data_backup):
        logging.info("Deleting previous run data backup '{}'".format(new_data_backup))
        rmtree(new_data_backup)
    logging.info("Backing up data from '{}' to '{}'".format(new_data, new_data_backup))
    copy_tree(new_data, new_data_backup, preserve_symlinks=True)
    for item in os.listdir(old_data):
        if item == 'zookeeper':
            logging.info("Skipping '{}'".format(item))
            old_zk_id = os.path.join(old_data, ZOOKEPER, MY_ID_FILE)
            if os.path.exists(old_zk_id):
                logging.info("Found zk myid file '{}'".format(old_zk_id))
                zk_folder = os.path.join(new_data, ZOOKEPER)
                if not os.path.exists(zk_folder):
                    logging.info("Creating zookeeper data folder '{}'".format(zk_folder))
                    os.makedirs(zk_folder)
                    logging.info("Copying zk myid file to '{}'".format(zk_folder))
                copy_file(old_zk_id, os.path.join(zk_folder, MY_ID_FILE))
        elif os.path.islink(os.path.join(old_data, item)):
            logging.info("Skipping link '{}'".format(os.readlink(os.path.join(old_data, item))))
        elif os.path.isdir(os.path.join(old_data, item)):
            logging.info("Copying folder '{}'".format(item))
            copy_tree(os.path.join(old_data, item), os.path.join(new_data, item), preserve_symlinks=True)
        else:
            copy_file(os.path.join(old_data, item), os.path.join(new_data, item))
            logging.info("Copying file '{}'".format(item))

if __name__ == "__main__":
    fsTran = FSTransformation("Copy data files excluding ZK folder")
    fusion_home_old = fsTran.get_old_fusion()
    fusion_home_new = fsTran.get_new_fusion()
    copy_data(fusion_home_old, fusion_home_new)
