#!/usr/bin/env python

import logging

from oie_transformation import OIETransformation
from schedule_helper import convertScheduleIntoJob


def convertTaskIntoTaskResource(schedule_id):
    '''
    Convert the schedule id into a fusion resource style uri for a task job
    :param schedule_id:
    :return:  a resource string based on the id provided in the schedule uri, or None if no id is present
    '''


    if schedule_id is None or 0 == len(schedule_id):
        logging.error("The  schedule_id may not be null or empty")
        return None

    logging.debug("The schedule_id was {}".format(schedule_id))
    resource="task:{}".format(schedule_id)
    logging.debug("The resource is {}".format(resource))
    return resource

def upgrade_schedules(oie_transformation):
    objects = oie_transformation.get_fusion_objects()
    schedules = objects.get("schedules",[])
    tasks = objects.get("tasks", [])
    jobs = objects.get("jobs", [])
    for schedule in schedules:
        job_config = convertScheduleIntoJob(schedule,convertTaskIntoTaskResource,schedule['id'])
        logging.info("Creating Job for Schedule {}".format(schedule['id']))
        jobs.append(job_config)

        task = {
            "id": schedule['id'],
            "type": "rest-call",
            "callParams": {
                "uri": schedule['callParams']['uri'],
                "method": schedule['callParams']['method'],
                "queryParams": schedule['callParams'].get("queryParams", {}),
                "headers": schedule['callParams'].get("headers", {}),
                "entity": schedule['callParams'].get("entity")
            },
            "schedule.adapted": "true",
            "schedule.createTime": schedule.get("createTime"),
            "schedule.creatorId": schedule.get("creatorId"),
            "schedule.creatorType": schedule.get("creatorId"),
            "schedule.startTime": schedule.get("startTime"),
            "schedule.endTime": schedule.get("endTime")
        }
        tasks.append(task)
        logging.info("Creating Task for Schedule {}".format(schedule['id']))

    objects['tasks'] = tasks
    objects['jobs'] = jobs
    del objects['schedules']

if __name__ == "__main__":
    oie_transformation = OIETransformation("Convert Schedule objects into Tasks and Jobs")
    upgrade_schedules(oie_transformation)
    oie_transformation.save_output()
