#!/usr/bin/env python

import logging
import json

from oie_transformation import OIETransformation
from schedule_helper import convertScheduleIntoJob


SCHEDULE_URI_SERVICE_CONNECTORS_JOBS="service://connectors/jobs/"

def isDataSourceJobURIWithID(callParamURI):
    '''
    determine if we examining a data source schedule that can be converted into a data source job (it has url prefix and the id)
    :param callParamURI: the uri or fusion resource uri for the schedule
    :return:  true if not null, has the required prefix, and there is something to use as an id
    '''
    return (None != callParamURI) and \
           callParamURI.startswith(SCHEDULE_URI_SERVICE_CONNECTORS_JOBS) and \
           0 < len(callParamURI[len(SCHEDULE_URI_SERVICE_CONNECTORS_JOBS):])


def convertScheduleUriIntoJobResource(scheduleUri):
    '''
    Convert the legacy uri of the schedule into a fusion resource style uri for a datasource job
    :param scheduleUri:
    :return:  a resource string based on the id provided in the schedule uri, or None if no id is present
    '''
    dataSourceId = scheduleUri[len(SCHEDULE_URI_SERVICE_CONNECTORS_JOBS):]

    if 0 == len(dataSourceId):
        logging.error("The  scheduleUri {} lacks an id part".format(scheduleUri))
        return None

    logging.debug("The scheduleUri was {} and we extracted the dataSourceId as {}".format(scheduleUri,dataSourceId))
    #resource = "urn:x-fusion:datasource:{}".format(dataSourceId)
    resource="datasource:{}".format(dataSourceId)
    logging.debug("The resource is {}".format(resource))
    return resource

if __name__=="__main__":
    # we are testing if jobs are already in the import/export file
    oieTran = OIETransformation("Datasource Schedules Transformation")
    objects = oieTran.get_fusion_objects()
    if "jobs" in objects:
        jobs = objects["jobs"]
        logging.debug("Found existing {} jobs".format(len(jobs)))
    else:
        jobs = []
        logging.debug("Found no existing jobs")
    # Now retrieve from zookeeper all of the data source schedules and convert them into jobs
    schedules = oieTran.read_full_zk_dump("/core/schedules/")
    for schedule in schedules:
        logging.debug("Examining the schedule with id {} for conversion an interval datasource job".format(schedule["id"]))
        logging.debug("The schedule looks like {}".format(json.dumps(schedule)))
        callParams = schedule["callParams"]
        logging.debug("callParams looks like {}".format(json.dumps(callParams)))
        if "uri" in callParams:
            callParamURI = callParams["uri"]
            logging.debug("callParamURI is {}".format(json.dumps(callParamURI)))
            if isDataSourceJobURIWithID(callParamURI):
                scheduleId = schedule["id"]
                logging.debug("Converting the schedule with id {} into an interval datasource job".format(scheduleId))
                # we have a data source job
                job = convertScheduleIntoJob(schedule,convertScheduleUriIntoJobResource,None)
                jobs.append(job)
                logging.info("Converted the schedule with id {} into an interval datasource job with resource {}".format(scheduleId,job["resource"]))

    objects["jobs"] = jobs
    oieTran.save_output()