 #!/usr/bin/env python

import json
import sys
import os
import argparse
import logging

from base_transformation import BaseTransformation

class OIETransformation(BaseTransformation):
    def __init__(self, description):
        logging.basicConfig(level=logging.INFO,
                     format="%(asctime)s - %(name)s - %(filename)s:%(lineno)d - %(levelname)s - %(message)s")
        parser = argparse.ArgumentParser(description=description)
        parser.add_argument("--input-file", required=True, help="File to modify")
        parser.add_argument("--output-file", required=True, help="File to output")
        parser.add_argument("--props-file", required=True, help="Properties file")
        parser.add_argument("--full-zk-dump", required=True, help="Full zk dump file")
        args = parser.parse_args()
        self.input_file = args.input_file
        self.output_file = args.output_file
        full_zk_dump = args.full_zk_dump
        props_file = args.props_file
        BaseTransformation.__init__(self, props_file, full_zk_dump)
        if not os.path.exists(self.input_file):
            sys.exit("Input file does not exist at path '{0}'.".format(self.input_file))
        self.input = json.load(open(self.input_file))
        if os.path.exists(self.output_file):
            sys.exit("Output file already exists at path '{0}'.".format(self.output_file))

    def get_fusion_objects(self):
        return self.input["objects"]

    def save_output(self):
        with open(self.output_file, 'w') as output_file:
            json.dump(self.input, output_file, indent=2)




