#!/usr/bin/env python

import os
import logging
from fs_transformation import FSTransformation
import json

from java.net import URL
from java.io import File
from java.io import IOException
from org.apache.commons.io import FileUtils

from org.apache.http.client.methods import HttpPut
from org.apache.http.entity import ContentType,FileEntity
from org.apache.http.impl.client import HttpClientBuilder
from org.apache.http.client.config import RequestConfig

def get_datasource_id_to_nametype(datasource_dict):
  res = {}
  for next_ds in datasource_dict:
    res[next_ds["id"]] = [next_ds["connector"], next_ds["type"]]
  return res

def upload_jdbc_drivers(api_connect, fusion_home_old, fusion_home_new):
  '''
  We need to upload files from 3.0.1/data/connectors/lucid.jdbc/jdbc/*/*.jar to the blob store as
  data sourc files.
  '''
  uploaded_already = []
  jdbc_path = os.path.join(fusion_home_old, 'data', 'connectors', 'lucid.jdbc', 'jdbc')
  if not os.path.exists(jdbc_path):
    logging.info("No %s directory exists, so there are no JDBC drivers to migrate.", jdbc_path)
    return
  for next_ds_dir in os.listdir(jdbc_path):
    logging.info("Listing the JDBC jars in %s", next_ds_dir)
    ds_dir_path = os.path.join(jdbc_path, next_ds_dir)
    for next_jar_file_name in os.listdir(ds_dir_path):
      next_jar_file = os.path.join(ds_dir_path, next_jar_file_name)
      if not next_jar_file_name in uploaded_already:
        logging.info("Next JDBC driver file %s. Uploading to new Fusion instance...", next_jar_file_name)
        uploaded_already.append(next_jar_file_name)
        entity = FileEntity(File(next_jar_file), ContentType.create("application/zip"));
        request = HttpPut("http://{0}/api/v1/blobs/{1}?resourceType=driver:jdbc".
                          format(api_connect, next_jar_file_name));
        request.setEntity(entity);
        params = RequestConfig.custom().setConnectTimeout(100000).setSocketTimeout(100000).setConnectionRequestTimeout(
          100000).build()
        client = HttpClientBuilder.create().setDefaultRequestConfig(params).build()
        response = client.execute(request);
        logging.info("JDBC Upload response: %s", response)

if __name__ == "__main__":
  fs_tran = FSTransformation("Copy JDBC drivers from old to new Fusion.")
  fusion_home_new = fs_tran.get_new_fusion()
  fusion_home_old = fs_tran.get_old_fusion()
  api_connect = fs_tran.get_api_connect()
  tmp_folder = os.path.join(fusion_home_old, "var", "upgrade", "tmp")
  upload_jdbc_drivers(api_connect, fusion_home_old, fusion_home_new)
