import logging
import json

from datetime import datetime

def convertSheduleIntoTrigger(schedule):
    '''
    convert the schedule data into a trigger
    :param schedule:
    :return:
    '''

    trigger = {}
    #set the trigger type
    trigger["type"] = "interval"
    # set the enabled flag
    trigger["enabled"]= schedule["active"]

    # set the timeunit
    if "repeatUnit" in schedule:
        repeatUnit = schedule["repeatUnit"].lower()
        logging.debug("repeatUnit discovered is {}".format(repeatUnit))
        if "millisecond" == repeatUnit:
            trigger["repeatUnit"] = "second"
            logging.info("The schedule with id {} had millisecond as its unit - replacing with second inside trigger".format(schedule["id"]))
        else:
            trigger["timeUnit"] = repeatUnit
    else:
        trigger["timeUnit"] = "day"
        trigger["enabled"] = False
        logging.info("The schedule with id {} did not specify a time unit - setting default of day and disabling".format(schedule["id"]))

    # set the starttime
    if "startTime" in schedule:
        trigger["startTime"] = schedule["startTime"]
    else:
        trigger["startTime"] = str(datetime.now().isoformat())
        logging.info("The schedule with id {} was missing a startTime - supplying now {}".format(schedule["id"],trigger["startTime"]))

    #set the interval amount
    if "interval" in schedule:
        if "repeatUnit" in schedule and "millisecond" == schedule["repeatUnit"] and 0 != int(schedule["interval"]):
            interval = int(schedule["interval"])
            trigger["interval"] = str(max(1,interval/1000))
        else:
            if 0 == int(schedule["interval"]) :
                trigger["interval"] = 1
                # leave the repeat unit as is because in this case, it was specified by the customer - don't undo their work
                trigger["enabled"] = False
                logging.info("The schedule with id {} had an interval set to 0 - setting interval to 1 and disabling".format(schedule["id"]))
            else:
                trigger["interval"] = schedule["interval"]
    else:
        trigger["interval"] = "1"
        trigger["enabled"] = False
        logging.info("The schedule with id {} did not specify an interval - setting default of 1 and disabling".format(schedule["id"]))

    flattnedTrigger = json.dumps(trigger)
    logging.debug("The trigger to replace schedule with id {} will have trigger {}".format(schedule["id"], flattnedTrigger))
    return trigger


def extractScheduleAdditionalProperties(schedule):
    '''
    take legacy schedule data and store in additional properties
    :param schedule:
    :return:
    '''
    # copy all into schedule.XXX for now until we know better what we want to hoard
    additionalProperties = {}
    for name,contents in schedule.items():
        legacyKey = "schedule." + name
        additionalProperties[legacyKey] = contents
    return additionalProperties


def convertScheduleIntoJob(schedule,resourceFunction,resourceFunctionArg):
    '''
    converts a schedule into a job
    :param schedule:
    :param resourceFunction - a function that creates the fusion resource from the provided schedule
    :param resourceFunctionArg - a value to be passed into the resource function if call params uri is not the source
    :return:
    '''
    # convert schedule into job configuration (see jobs endpoint and com.lucidworks.apollo.client.resources.JobClientResource#getJobConfig)
    # TODO change dataSourceJob to job to make this code more generic
    dataSourceJob = {}
    logging.debug("The schedule being converted into a job is {}".format(json.dumps(schedule)))
    # callParams and uri are already verified by caller, so no defensive code needed here
    if None == resourceFunctionArg:
        dataSourceJob["resource"] = resourceFunction(schedule["callParams"]["uri"])
    else:
        dataSourceJob["resource"] = resourceFunction(resourceFunctionArg)

    if "active" in schedule:
        dataSourceJob["enabled"] =  schedule["active"]
    else:
        dataSourceJob["enabled"] = True
    triggers = []
    trigger = convertSheduleIntoTrigger(schedule)
    triggers.append(trigger)
    dataSourceJob["triggers"] = triggers
    dataSourceJob["default"] = False
    dataSourceJob["additionalProperties"] = extractScheduleAdditionalProperties(schedule)
    logging.debug("The newly created job for schedule with id {} is {}".format(schedule["id"],json.dumps(dataSourceJob)))
    return dataSourceJob