 #!/usr/bin/env python

import logging

from zk_transformation import ZKTransformation

crawl_db_prefix = "crawldb_"
history_name = "system_history"
history_name_custom = None
signals_suffix = "_signals"
signals_suffix_custom = None
aggr_suffix = "_aggr"
signals_aggr_suffix = signals_suffix + aggr_suffix
signals_aggr_suffix_custom = None
message_name = "system_messages"
message_name_custom = None
taxonomy_suffix = "_stored_parameters"
blobs_name = "system_blobs"
blobs_name_custom = None


def change_type(zk_tran, collection):
    if collection["type"] not in ["DATA", "SIGNALS"]:
        return collection
    if collection["id"].startswith(crawl_db_prefix):
        collection["type"] = "CRAWL_DB"
    elif collection["id"] == history_name or collection["id"] == history_name_custom:
        collection["type"] = "HISTORY"
    elif collection["id"].endswith(signals_aggr_suffix) or (signals_aggr_suffix_custom is not None and collection["id"].endswith(signals_aggr_suffix_custom)):
        collection["type"] = "SIGNALS_AGGREGATION"
    elif collection["id"] == message_name or collection["id"] == message_name_custom:
        collection["type"] = "MESSAGES"
    elif collection["id"].endswith(taxonomy_suffix):
        collection["type"] = "TAXONOMY"
    elif collection["id"] == blobs_name or collection["id"] == blobs_name_custom:
        collection["type"] = "BLOBS"
    else:
        return collection
    log_change(collection)
    return collection


def log_change(collection):
    logging.info("Set collection {} type to {}".format(collection["id"], collection["type"]))


if __name__ == "__main__":
    zkTran = ZKTransformation("Set proper types for system collections")
    history_name_custom = zkTran.get_zk_property("com.lucidworks.apollo.history.collectionName")
    if history_name_custom is not None:
        logging.info("Will use {} for History Collection name".format(history_name_custom))
    signals_suffix_custom = zkTran.get_zk_property("com.lucidworks.apollo.solr.signal.suffix")
    aggr_suffix_custom = zkTran.get_zk_property("com.lucidworks.apollo.solr.signal.aggr.suffix")
    if aggr_suffix_custom is not None:
        if signals_suffix_custom is None:
            signals_aggr_suffix_custom = signals_suffix + aggr_suffix_custom
        else:
            signals_aggr_suffix_custom = signals_suffix_custom + aggr_suffix_custom
        logging.info("Will use {} for Signal aggregation collections suffix".format(signals_aggr_suffix_custom))
    elif signals_suffix_custom is not None:
        signals_aggr_suffix_custom = signals_suffix_custom + aggr_suffix
        logging.info("Will use {} for Signal aggregation collections suffix".format(signals_aggr_suffix_custom))
    message_name_custom = zkTran.get_zk_property("com.lucidworks.apollo.messaging.collectionName")
    if message_name_custom is not None:
        logging.info("Will use {} for Messages Collection name".format(message_name_custom))
    blobs_name_custom = zkTran.get_zk_property("com.lucidworks.apollo.blobs.solr.collection")
    if blobs_name_custom is not None:
        logging.info("Will use {} for Blobs Collection name".format(blobs_name_custom))

    zkTran.update_collections(change_type, False)

