# !/usr/bin/env python

import logging
import copy

from zk_transformation import ZKTransformation

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

def update_role_permissions(zkTran, role):
    if role['name'] == 'developer':
        permissions_to_add = [{"methods": ["GET","POST","PUT","DELETE","HEAD"],"path":"/tasks/**"},
                              {"methods": ["GET","POST","PUT","DELETE","HEAD"],"path": "/links/**"},
                              {"methods": ["GET","POST","PUT","DELETE","HEAD"],"path": "/groups/**"},
                              {"methods": ["GET","POST","PUT","DELETE","HEAD"],"path": "/jobs/**"}]
        role['permissions'] = role['permissions'] + permissions_to_add
        logging.info("Adding jobs, tasks, links and groups permissions to developer role. ")

        ui_permissions_to_add = ["tasks","links","groups","blobs","jobs"]
        role['ui-permissions'] = role['ui-permissions'] + ui_permissions_to_add
        logging.info("Adding jobs, tasks, links, blobs and groups ui-permissions to developer role. ")

    else:
        for permission in role['permissions']:
            if permission['path'] == "/scheduler/**":
                jobs_permission = copy.copy(permission)
                jobs_permission['path'] = jobs_permission['path'].replace("scheduler", "jobs")
                tasks_permission = copy.copy(permission)
                tasks_permission['path'] = tasks_permission['path'].replace("scheduler", "tasks")
                role['permissions'] = role['permissions'] + [jobs_permission, tasks_permission]
                logging.info("Adding /jobs/** and /tasks/** permissions to {} role. ".format(role['name']))

            if permission['path'] == "/aggregator/**":
                spark_permission = copy.copy(permission)
                spark_permission['path'] = spark_permission['path'].replace("aggregator", "spark")
                role['permissions'] = role['permissions'] + [spark_permission]
                logging.info("Adding /spark/** permissions to {} role.".format(role['name']))

        for ui_permission in role['ui-permissions']:
            if ui_permission == "scheduler":
                role['ui-permissions'] = role['ui-permissions'] + ["tasks", "jobs"]
                logging.info("Adding tasks and jobs ui-permissions to {} role.".format(role['name']))

    return role

if __name__ == "__main__":
    zkTran = ZKTransformation('''Updating permissions within roles in zookeeper.''')
    zkTran.update_roles(update_role_permissions, False)
    logging.info("Custom permissions not in /** not assigned to roles and will have to be done manually.")