# !/usr/bin/env python

import logging
import copy

from zk_transformation import ZKTransformation

logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

def update_user_permissions(zkTran, user):

    for permission in user['permissions']:
        if permission['path'] == "/scheduler/**":
            jobs_permission = copy.copy(permission)
            jobs_permission['path'] = jobs_permission['path'].replace("scheduler", "jobs")
            tasks_permission = copy.copy(permission)
            tasks_permission['path'] = tasks_permission['path'].replace("scheduler", "tasks")
            user['permissions'] = user['permissions'] + [jobs_permission, tasks_permission]
            logging.info("Adding /jobs/** and /tasks/** permissions to user {}'s permissions.".format(user['username']))

        if permission['path'] == "/aggregator/**":
            spark_permission = copy.copy(permission)
            spark_permission['path'] = spark_permission['path'].replace("aggregator", "spark")
            user['permissions'] = user['permissions'] + [spark_permission]
            logging.info("Adding /spark/** permissions to user {}'s permissions.".format(user['username']))

    return user

if __name__ == "__main__":
    zkTran = ZKTransformation('''Updating permissions within roles in zookeeper.''')
    zkTran.update_users(update_user_permissions, False)
    logging.info("Custom permissions not in /** not assigned to users and will have to be done manually.")
